==> jc-1.4.0.tar.gz: javax/naming/NotContextException.h <==
// public class javax.naming.NotContextException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fadee18b7599c8d5 javax_naming_NamingException
// @dep_class fef246831f6407ce javax_naming_NotContextException

// header file dependencies
// @dep_header javax_naming_NamingException

#include "javax/naming/NamingException.h"

#ifndef _JC_javax_naming_NotContextException_H_
#define _JC_javax_naming_NotContextException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_naming_NotContextException$sub_refs	_jc_javax_naming_NotContextException$sub_refs;
typedef struct _jc_javax_naming_NotContextException$sub_nonrefs	_jc_javax_naming_NotContextException$sub_nonrefs;
typedef struct _jc_javax_naming_NotContextException$refs	_jc_javax_naming_NotContextException$refs;
typedef struct _jc_javax_naming_NotContextException$nonrefs	_jc_javax_naming_NotContextException$nonrefs;
typedef struct _jc_javax_naming_NotContextException$object	_jc_javax_naming_NotContextException$object;

typedef const struct _jc_javax_naming_NotContextException$vmethods	_jc_javax_naming_NotContextException$vmethods;
typedef const struct _jc_javax_naming_NotContextException$vtable	_jc_javax_naming_NotContextException$vtable;
typedef const struct _jc_javax_naming_NotContextException$vtype	_jc_javax_naming_NotContextException$vtype;

// Constructors
extern void _jc_javax_naming_NotContextException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_NotContextException$object *);
extern void _jc_javax_naming_NotContextException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_NotContextException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_naming_NotContextException$vmethods {
};

// Vtable
struct _jc_javax_naming_NotContextException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_naming_NamingException$vmethods	javax_naming_NamingException;
	_jc_javax_naming_NotContextException$vmethods	javax_naming_NotContextException;
};

// Vtype
struct _jc_javax_naming_NotContextException$vtype {
	_jc_type			type;
	_jc_javax_naming_NotContextException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_NotContextException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_NotContextException$refs {
    _jc_javax_naming_NotContextException$sub_refs	javax_naming_NotContextException;
    _jc_javax_naming_NamingException$sub_refs	javax_naming_NamingException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_NotContextException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_NotContextException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_naming_NamingException$sub_nonrefs	javax_naming_NamingException;
    _jc_javax_naming_NotContextException$sub_nonrefs	javax_naming_NotContextException;
};

// Object instance structure
struct _jc_javax_naming_NotContextException$object {
	_jc_javax_naming_NotContextException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_NotContextException$vtype	*vtype;
	_jc_javax_naming_NotContextException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_NotContextException$vtype _jc_javax_naming_NotContextException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_NotContextException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_NotContextException$class_object;

#endif	/* _JC_javax_naming_NotContextException_H_ */

==> jc-1.4.6.tar.gz: javax/naming/NotContextException.h <==
// public class javax.naming.NotContextException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fadee18b7599c8d5 javax_naming_NamingException
// @dep_class fef246831f6407ce javax_naming_NotContextException

// header file dependencies
// @dep_header javax_naming_NamingException

#include "javax/naming/NamingException.h"

#ifndef _JC_javax_naming_NotContextException_H_
#define _JC_javax_naming_NotContextException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_naming_NotContextException$sub_refs	_jc_javax_naming_NotContextException$sub_refs;
typedef struct _jc_javax_naming_NotContextException$sub_nonrefs	_jc_javax_naming_NotContextException$sub_nonrefs;
typedef struct _jc_javax_naming_NotContextException$refs	_jc_javax_naming_NotContextException$refs;
typedef struct _jc_javax_naming_NotContextException$nonrefs	_jc_javax_naming_NotContextException$nonrefs;
typedef struct _jc_javax_naming_NotContextException$object	_jc_javax_naming_NotContextException$object;

typedef const struct _jc_javax_naming_NotContextException$vmethods	_jc_javax_naming_NotContextException$vmethods;
typedef const struct _jc_javax_naming_NotContextException$vtable	_jc_javax_naming_NotContextException$vtable;
typedef const struct _jc_javax_naming_NotContextException$vtype	_jc_javax_naming_NotContextException$vtype;

// Constructors
extern void _jc_javax_naming_NotContextException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_NotContextException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_NotContextException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_NotContextException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_naming_NotContextException$vmethods {
};

// Vtable
struct _jc_javax_naming_NotContextException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_naming_NamingException$vmethods	javax_naming_NamingException;
	_jc_javax_naming_NotContextException$vmethods	javax_naming_NotContextException;
};

// Vtype
struct _jc_javax_naming_NotContextException$vtype {
	_jc_type			type;
	_jc_javax_naming_NotContextException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_NotContextException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_NotContextException$refs {
    _jc_javax_naming_NotContextException$sub_refs	javax_naming_NotContextException;
    _jc_javax_naming_NamingException$sub_refs	javax_naming_NamingException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_NotContextException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_NotContextException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_naming_NamingException$sub_nonrefs	javax_naming_NamingException;
    _jc_javax_naming_NotContextException$sub_nonrefs	javax_naming_NotContextException;
};

// Object instance structure
struct _jc_javax_naming_NotContextException$object {
	_jc_javax_naming_NotContextException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_NotContextException$vtype	*vtype;
	_jc_javax_naming_NotContextException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_NotContextException$vtype _jc_javax_naming_NotContextException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_NotContextException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_NotContextException$class_object;

#endif	/* _JC_javax_naming_NotContextException_H_ */
